==> aloe-1.1b.tar.gz: aloe-1.1b/hw_api/lnx/src/parse_str.h <==
/*
 * parse_str.h
 *
 * Copyright (c) 2009 Ismael Gomez-Miguelez, UPC <ismael.gomez at tsc.upc.edu>,
 *                    Xavier Reves, UPC <xavier.reves at tsc.upc.edu>
 * All rights reserved.
 *
 *
 * This file is part of ALOE.
 *
 * ALOE is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * ALOE is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with ALOE.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#define ITF_ID		0
#define ITF_PORT	1
#define ITF_ADDRESS	2
#define ITF_MODE	3
#define ITF_BW		4
#define ITF_DELAY	5
#define ITF_TYPE	6
#define NOF_ITF_PARAMS	7

#define DAEMON_NAME		0
#define DAEMON_PATH		1
#define DAEMON_RUNABLE		2
#define DAEMON_OUTPUT		3
#define NOF_DAEMON_PARAMS	4

#define CPU_MIPS		0
#define CPU_TSLOT		1
#define CPU_VIRTUAL		2
#define CPU_DAEMON		3
#define CPU_OUTPUT		4
#define CPU_REPORT		5
#define CPU_DEBUG		6
#define CPU_PRIORITY		7
#define CPU_RESPATH		8
#define CPU_LOCK		9
#define CPU_NAME                10
#define CPU_FULLBRIDGE          11
#define CPU_ENDIAN              12
#define CPU_CORES               13
#define NOF_CPU_PARAMS		14

#define RES_ID			0
#define RES_NAME		1
#define RES_OPTS		2
#define NOF_RES_PARAMS		3

#define PLT_ID			0
#define PLT_OUT_ID		1
#define PLT_IN_ID		2
#define NOF_SYNC_PLT_PARAMS	3

#define PLT_MOD_CFG_ID		3
#define NOF_MAN_PLT_PARAMS	4

int parse_cpu_cfg(FILE *f, struct launch_daemons *daemon_db, int max_d, struct hw_api_db *hwapi_db);
int parse_itf_cfg(FILE *f, struct ext_itf *ext_itf, int max_itf);

==> aloe-1.3.tar.gz: aloe-1.3/hw_api/lnx/src/parse_str.h <==
/*
 * parse_str.h
 *
 * Copyright (c) 2009 Ismael Gomez-Miguelez, UPC <ismael.gomez at tsc.upc.edu>,
 *                    Xavier Reves, UPC <xavier.reves at tsc.upc.edu>
 * All rights reserved.
 *
 *
 * This file is part of ALOE.
 *
 * ALOE is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * ALOE is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with ALOE.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#define ITF_ID		0
#define ITF_PORT	1
#define ITF_ADDRESS	2
#define ITF_MODE	3
#define ITF_BW		4
#define ITF_DELAY	5
#define ITF_TYPE	6
#define NOF_ITF_PARAMS	7

#define CPU_MIPS		0
#define CPU_TSLOT		1
#define CPU_DAEMON		2
#define CPU_OUTPUT		3
#define CPU_DEBUG		4
#define CPU_RESPATH		5
#define CPU_LOCK		6
#define CPU_NAME                7
#define CPU_FULLBRIDGE          8
#define CPU_ENDIAN              9
#define CPU_CORES               10
#define CPU_BTATEXIT            11
#define CPU_BTATTERM            12
#define CPU_DLIST               13
#define CPU_ITFDELAY            14
#define CPU_ARCH                15
#define CPU_FLUSH               16
#define NOF_CPU_PARAMS		17

#define RES_ID			0
#define RES_NAME		1
#define RES_OPTS		2
#define NOF_RES_PARAMS		3

#define PLT_ID			0
#define PLT_OUT_ID		1
#define PLT_IN_ID		2
#define NOF_SYNC_PLT_PARAMS	3

#define PLT_MOD_CFG_ID		3
#define NOF_MAN_PLT_PARAMS	4

int parse_cpu_cfg(FILE *f, struct launch_daemons *daemon_db, int max_d, struct hw_api_db *hwapi_db);
int parse_itf_cfg(FILE *f, struct ext_itf *ext_itf, int max_itf);
